@@ -6,7 +6,14 @@ if [ $# != 2 ]; then
 fi;
 
 case "$1" in
-	desktop|win32|pepperpad3)
+	desktop|win32)
+		toolbar_file=data/default/toolbar.desktop.xml
+		fullscreen_toolbar_file=data/default/fullscreen_toolbar.desktop.xml
+		;;
+	maemo)
+		toolbar_file=data/default/toolbar.maemo.xml
+		;;
+	pepperpad3)
 		toolbar_file=data/default/toolbar.full.xml
 		;;
 	zaurus_640x480)
@@ -32,6 +39,10 @@ if [ "$toolbar_file" != "" ]; then
 	install -m 0644 $toolbar_file $2/toolbar.xml;
 fi;
 
+if [ "$fullscreen_toolbar_file" != "" ]; then
+	install -m 0644 $fullscreen_toolbar_file $2/fullscreen_toolbar.xml;
+fi;
+
 if [ "$menubar_file" != "" ]; then
 	install -m 0644 $menubar_file $2/menubar.xml;
 fi;
