@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2008-2009 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,5 +19,7 @@
 
 #include "XMLNamespace.h"
 
-const std::string XMLNamespace::DublinCore = "http://purl.org/dc/elements/1.1/";
+const std::string XMLNamespace::DublinCorePrefix = "http://purl.org/dc/elements";
+const std::string XMLNamespace::DublinCoreLegacyPrefix = "http://purl.org/metadata/dublin_core";
 const std::string XMLNamespace::XLink = "http://www.w3.org/1999/xlink";
+const std::string XMLNamespace::OpenPackagingFormat = "http://www.idpf.org/2007/opf";
