@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,7 +28,6 @@
 
 #include "BookTextView.h"
 #include "FBReader.h"
-#include "FBReaderActions.h"
 
 #include "../bookmodel/FBTextKind.h"
 #include "../bookmodel/BookModel.h"
@@ -48,7 +47,6 @@ BookTextView::BookTextView(FBReader &reader, shared_ptr<ZLPaintContext> context)
 	myCurrentPointInStack = 0;
 	myMaxStackSize = 20;
 	myLockUndoStackChanges = false;
-	myScrollingSpeed = 0;
 }
 
 BookTextView::~BookTextView() {
@@ -196,7 +194,7 @@ void BookTextView::undoPageMove() {
 		gotoPosition(pos.first, pos.second, 0);
 		myLockUndoStackChanges = false;
 
-		fbreader().refreshWindow();
+		application().refreshWindow();
 	}
 }
 
@@ -217,11 +215,11 @@ void BookTextView::redoPageMove() {
 			myPositionStack.pop_back();
 		}
 
-		fbreader().refreshWindow();
+		application().refreshWindow();
 	}
 }
 
-bool BookTextView::getHyperlinkId(const ZLTextElementArea &area, std::string &id, bool &isExternal) const {
+bool BookTextView::getHyperlinkInfo(const ZLTextElementArea &area, std::string &id, std::string &type) const {
 	if ((area.Kind != ZLTextElement::WORD_ELEMENT) &&
 			(area.Kind != ZLTextElement::IMAGE_ELEMENT)) {
 		return false;
@@ -237,6 +235,7 @@ bool BookTextView::getHyperlinkId(const ZLTextElementArea &area, std::string &id
 			if (control.isHyperlink()) {
 				hyperlinkKind = control.kind();
 				id = ((const ZLTextHyperlinkControlEntry&)control).label();
+				type = ((const ZLTextHyperlinkControlEntry&)control).hyperlinkType();
 			} else if (!control.isStart() && (control.kind() == hyperlinkKind)) {
 				hyperlinkKind = REGULAR;
 			}
@@ -244,17 +243,20 @@ bool BookTextView::getHyperlinkId(const ZLTextElementArea &area, std::string &id
 		cursor.nextWord();
 	}
 
-	isExternal = hyperlinkKind == EXTERNAL_HYPERLINK;
 	return hyperlinkKind != REGULAR;
 }
 
 bool BookTextView::_onStylusPress(int x, int y) {
+	return false;
+}
+
+bool BookTextView::onStylusClick(int x, int y, int count) {
 	const ZLTextElementArea *area = elementByCoordinates(x, y);
 	if (area != 0) {
 		std::string id;
-		bool isExternal;
-		if (getHyperlinkId(*area, id, isExternal)) {
-			fbreader().tryShowFootnoteView(id, isExternal);
+		std::string type;
+		if (getHyperlinkInfo(*area, id, type)) {
+			fbreader().tryShowFootnoteView(id, type);
 			return true;
 		}
 		
@@ -268,69 +270,44 @@ bool BookTextView::_onStylusPress(int x, int y) {
 		}
 	}
 
-	if (!isSelectionEnabled()) {
-		myLatestUpdateY = y;	
-		myLatestUpdateTime = ZLTime();
-		return true;
+	return FBView::onStylusClick(x, y, count);
+}
+
+bool BookTextView::_onStylusRelease(int x, int y) {
+	if (!isReleasedWithoutMotion()) {
+		return false;
+	}
+
+	const ZLTextElementArea *area = elementByCoordinates(x, y);
+	if (area != 0) {
+		std::string id;
+		std::string type;
+		if (getHyperlinkInfo(*area, id, type)) {
+			fbreader().tryShowFootnoteView(id, type);
+			return true;
+		}
+		
+		if (fbreader().isDictionarySupported() &&
+				fbreader().EnableSingleClickDictionaryOption.value()) {
+			const std::string txt = word(*area);
+			if (!txt.empty()) {
+				fbreader().openInDictionary(txt);
+				return true;
+			}
+		}
 	}
 
 	return false;
 }
 
-bool BookTextView::onStylusMove(int x, int y) {
+bool BookTextView::_onStylusMove(int x, int y) {
 	const ZLTextElementArea *area = elementByCoordinates(x, y);
 	std::string id;
-	bool isExternal;
-	fbreader().setHyperlinkCursor((area != 0) && getHyperlinkId(*area, id, isExternal));
+	std::string type;
+	fbreader().setHyperlinkCursor((area != 0) && getHyperlinkInfo(*area, id, type));
 	return true;
 }
 
-bool BookTextView::onStylusMovePressed(int x, int y) {
-	if (!isSelectionEnabled()) {
-		int timeDiff = myLatestUpdateTime.millisecondsTo(ZLTime());
-		int yDiff = y - myLatestUpdateY;
-		if ((timeDiff > 0) && (abs(yDiff) >= 25)) {
-			int fingerSpeed = 1000 * yDiff / timeDiff;
-			if (abs(fingerSpeed) > 5000) {
-				myScrollingSpeed += fingerSpeed / 1000;
-				myLatestUpdateY = y;
-			}
-		}
-		bool doRepaint = false;
-		if (myScrollingSpeed > 0) {
-			scrollPage(false, SCROLL_LINES, myScrollingSpeed--);
-			doRepaint = true;
-		} else if (myScrollingSpeed < 0) {
-			scrollPage(true, SCROLL_LINES, -(myScrollingSpeed++));
-			doRepaint = true;
-		} else /*if (myScrollingSpeed == 0)*/ {
-			if (y > myLatestUpdateY + 25) {
-				scrollPage(false, SCROLL_LINES, 1);
-				myLatestUpdateY += 25;
-				doRepaint = true;
-			} else if (y < myLatestUpdateY - 25) {
-				scrollPage(true, SCROLL_LINES, 1);
-				myLatestUpdateY -= 25;
-				doRepaint = true;
-			}
-		}
-		if (doRepaint) {
-			myLatestUpdateTime = ZLTime();
-			fbreader().refreshWindow();
-		}
-		return true;
-	}
-	return FBView::onStylusMovePressed(x, y);
-}
-
-bool BookTextView::onStylusRelease(int x, int y) {
-	myScrollingSpeed = 0;
-	if (FBView::onStylusRelease(x, y)) {
-		return true;
-	}
-	return false;
-}
-
 shared_ptr<ZLTextView::PositionIndicator> BookTextView::createPositionIndicator(const ZLTextPositionIndicatorInfo &info) {
 	return new PositionIndicatorWithLabels(*this, info);
 }
@@ -383,11 +360,5 @@ void BookTextView::paint() {
 	FBView::paint();
 	std::string pn;
 	ZLStringUtil::appendNumber(pn, pageIndex());
-	pn += '/';
-	ZLStringUtil::appendNumber(pn, pageNumber());
 	fbreader().setVisualParameter(FBReader::PageIndexParameter, pn);
 }
-
-bool BookTextView::isSelectionEnabled() const {
-	return ZLStringOption(ZLCategoryKey::LOOK_AND_FEEL, "ToggleButtonGroup", "finger", "").value() == ActionCode::SELECT_TEXT;
-}
