@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +23,6 @@
 #include <deque>
 
 #include <ZLOptions.h>
-#include <ZLTime.h>
 
 #include "FBView.h"
 
@@ -48,11 +47,10 @@ public:
 
 	void scrollToHome();
 
-private:
 	bool _onStylusPress(int x, int y);
-	bool onStylusMove(int x, int y);
-	bool onStylusMovePressed(int x, int y);
-	bool onStylusRelease(int x, int y);
+	bool _onStylusMove(int x, int y);
+	bool _onStylusRelease(int x, int y);
+	bool onStylusClick(int x, int y, int count);
 
 private:
 	typedef std::pair<int,int> Position;
@@ -62,14 +60,12 @@ private:
 
 	void preparePaintInfo();
 
-	bool getHyperlinkId(const ZLTextElementArea &area, std::string &id, bool &isExternal) const;
+	bool getHyperlinkInfo(const ZLTextElementArea &area, std::string &id, std::string &type) const;
 
 	shared_ptr<PositionIndicator> createPositionIndicator(const ZLTextPositionIndicatorInfo &info);
 
 	void paint();
 
-	bool isSelectionEnabled() const;
-
 private:
 	class PositionIndicatorWithLabels : public PositionIndicator {
 
@@ -93,10 +89,6 @@ private:
 	unsigned int myMaxStackSize;
 
 	bool myLockUndoStackChanges;
-
-	int myLatestUpdateY;
-	ZLTime myLatestUpdateTime;
-	int myScrollingSpeed;
 };
 
 inline void BookTextView::preparePaintInfo() {
