@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,15 +29,17 @@ const std::string CollectionModel::AuthorInfoImageId = "authorInfo";
 const std::string CollectionModel::SeriesOrderImageId = "seriesOrder";
 const std::string CollectionModel::TagInfoImageId = "tagInfo";
 const std::string CollectionModel::RemoveTagImageId = "removeTag";
+const std::string CollectionModel::StrutImageId = "strut";
 
 CollectionModel::CollectionModel(CollectionView &view, BookCollection &collection) : ZLTextTreeModel(), myView(view), myCollection(collection) {
 	const std::string prefix = ZLibrary::ApplicationImageDirectory() + ZLibrary::FileNameDelimiter;
-	myImageMap[RemoveBookImageId] = new ZLFileImage("image/png", prefix + "tree-remove.png", 0);
+	myImageMap[RemoveBookImageId] = new ZLFileImage("image/png", prefix + "tree-removebook.png", 0);
 	myImageMap[BookInfoImageId] = new ZLFileImage("image/png", prefix + "tree-bookinfo.png", 0);
 	myImageMap[AuthorInfoImageId] = new ZLFileImage("image/png", prefix + "tree-authorinfo.png", 0);
-	myImageMap[SeriesOrderImageId] = new ZLFileImage("image/png", prefix + "tree-order.png", 0);
+	myImageMap[SeriesOrderImageId] = new ZLFileImage("image/png", prefix + "tree-order-series.png", 0);
 	myImageMap[TagInfoImageId] = new ZLFileImage("image/png", prefix + "tree-taginfo.png", 0);
 	myImageMap[RemoveTagImageId] = new ZLFileImage("image/png", prefix + "tree-removetag.png", 0);
+	myImageMap[StrutImageId] = new ZLFileImage("image/png", prefix + "tree-strut.png", 0);
 }
 
 CollectionModel::~CollectionModel() {
@@ -159,6 +161,16 @@ void CollectionModel::buildOrganizedByTags(bool buildAuthorTree) {
 }
 
 void CollectionModel::buildOrganizedByAuthors() {
+	if (myView.ShowAllBooksTagOption.value()) {
+		const ZLResource &resource = ZLResource::resource("library");
+		ZLTextTreeParagraph *allBooksParagraph = createParagraph();
+		insertText(LIBRARY_ENTRY, resource["allBooks"].value());
+		addBidiReset();
+		insertImage(StrutImageId);
+		myParagraphToTag[allBooksParagraph] = CollectionView::SpecialTagAllBooks;
+		addBooks(false, myCollection.books(), allBooksParagraph);
+	}
+
 	addBooksTree(myCollection.books(), 0);
 }
 
@@ -213,6 +225,7 @@ void CollectionModel::addBooksTree(const Books &books, ZLTextTreeParagraph *root
 			authorParagraph = createParagraph(root);
 			insertText(LIBRARY_ENTRY, author->displayName());
 			addBidiReset();
+			insertImage(StrutImageId);
 			//insertImage(AuthorInfoImageId);
 			currentSeriesName.erase();
 			seriesParagraph = 0;
@@ -227,6 +240,7 @@ void CollectionModel::addBooksTree(const Books &books, ZLTextTreeParagraph *root
 			seriesParagraph = createParagraph(authorParagraph);
 			insertText(LIBRARY_ENTRY, seriesName);
 			addBidiReset();
+			insertImage(StrutImageId);
 			//insertImage(SeriesOrderImageId);
 		}
 		ZLTextTreeParagraph *bookParagraph = createParagraph(
@@ -296,3 +310,7 @@ void CollectionModel::removeBook(BookDescriptionPtr book) {
 		}
 	}
 }
+
+bool CollectionModel::empty() const {
+	return myCollection.books().empty();
+}
