@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,6 +38,7 @@ public:
 	static const std::string SeriesOrderImageId;
 	static const std::string TagInfoImageId;
 	static const std::string RemoveTagImageId;
+	static const std::string StrutImageId;
 
 public:
 	CollectionModel(CollectionView &view, BookCollection &collection);
@@ -51,6 +52,8 @@ public:
 
 	void removeBook(BookDescriptionPtr book);
 
+	bool empty() const;
+
 private:
 	void build();
 	void buildOrganizedByTags(bool buildAuthorTree);
