@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,8 +31,8 @@ ContentsView::ContentsView(FBReader &reader, shared_ptr<ZLPaintContext> context)
 ContentsView::~ContentsView() {
 }
 
-bool ContentsView::onStylusMove(int x, int y) {
-	int index = paragraphIndexByCoordinate(y);
+bool ContentsView::_onStylusMove(int x, int y) {
+	int index = paragraphIndexByCoordinates(x, y);
 	if ((index < 0) || ((int)model()->paragraphsNumber() <= index)) {
 		fbreader().setHyperlinkCursor(false);
 		return true;
@@ -46,7 +46,7 @@ bool ContentsView::onStylusMove(int x, int y) {
 }
 
 bool ContentsView::_onStylusPress(int x, int y) {
-	int index = paragraphIndexByCoordinate(y);
+	int index = paragraphIndexByCoordinates(x, y);
 	if ((index < 0) || ((int)model()->paragraphsNumber() <= index)) {
 		return false;
 	}
@@ -96,6 +96,7 @@ void ContentsView::gotoReference() {
 	model()->removeAllMarks();
 	const size_t selected = currentTextViewParagraph();
 	highlightParagraph(selected);
+	preparePaintInfo();
 	gotoParagraph(selected);
 	scrollPage(false, ZLTextView::SCROLL_PERCENTAGE, 40);
 }
