@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ public:
 
 private:
 	bool _onStylusPress(int x, int y);
-	bool onStylusMove(int x, int y);
+	bool _onStylusMove(int x, int y);
 };
 
 #endif /* __CONTENTSVIEW_H__ */
