@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,10 +36,11 @@
 #include "FootnoteView.h"
 #include "ContentsView.h"
 #include "CollectionView.h"
-#include "RecentBooksView.h"
+#include "NetLibraryView.h"
 #include "RecentBooksPopupData.h"
 #include "BookInfoDialog.h"
 #include "TimeUpdater.h"
+#include "NetworkOperationRunnable.h"
 
 #include "../migration/migrate.h"
 
@@ -100,10 +101,10 @@ FBReader::FBReader(const std::string &bookToOpen) :
 	TapScrollingOnFingerOnlyOption(ZLCategoryKey::CONFIG, TAP_SCROLLING, "FingerOnly", true),
 	UseSeparateBindingsOption(ZLCategoryKey::CONFIG, "KeysOptions", "UseSeparateBindings", false),
 	EnableSingleClickDictionaryOption(ZLCategoryKey::CONFIG, "Dictionary", "SingleClick", false),
-	myBindings0("Keys"),
-	myBindings90("Keys90"),
-	myBindings180("Keys180"),
-	myBindings270("Keys270"),
+	myBindings0(new ZLKeyBindings("Keys")),
+	myBindings90(new ZLKeyBindings("Keys90")),
+	myBindings180(new ZLKeyBindings("Keys180")),
+	myBindings270(new ZLKeyBindings("Keys270")),
 	myBookToOpen(bookToOpen),
 	myBookAlreadyOpen(false),
 	myActionOnCancel(UNFULLSCREEN) {
@@ -113,25 +114,25 @@ FBReader::FBReader(const std::string &bookToOpen) :
 	myFootnoteView = new FootnoteView(*this, context());
 	myContentsView = new ContentsView(*this, context());
 	myCollectionView = new CollectionView(*this, context());
-	myRecentBooksView = new RecentBooksView(*this, context());
+	myNetLibraryView = new NetLibraryView(*this, context());
 	myRecentBooksPopupData = new RecentBooksPopupData(*this);
 	myMode = UNDEFINED_MODE;
 	myPreviousMode = BOOK_TEXT_MODE;
 	setMode(BOOK_TEXT_MODE);
 
-	addAction(ActionCode::SHOW_READING, new UndoAction(*this, FBReader::BOOK_COLLECTION_MODE));
-	addAction(ActionCode::SHOW_COLLECTION, new SetModeAction(*this, FBReader::BOOK_COLLECTION_MODE, FBReader::BOOK_TEXT_MODE | FBReader::RECENT_BOOKS_MODE));
-	//addAction(ActionCode::SHOW_LAST_BOOKS, new SetModeAction(*this, FBReader::RECENT_BOOKS_MODE, FBReader::BOOK_TEXT_MODE | FBReader::CONTENTS_MODE));
+	addAction(ActionCode::SHOW_READING, new UndoAction(*this, FBReader::ALL_MODES & ~FBReader::BOOK_TEXT_MODE));
+	addAction(ActionCode::SHOW_COLLECTION, new SetModeAction(*this, FBReader::BOOK_COLLECTION_MODE, FBReader::BOOK_TEXT_MODE | FBReader::CONTENTS_MODE));
+	addAction(ActionCode::SHOW_NET_LIBRARY, new ShowNetworkLibraryAction(*this));
+	addAction(ActionCode::SEARCH_ON_NETWORK, new SearchOnNetworkAction(*this));
+	addAction(ActionCode::ADVANCED_SEARCH_ON_NETWORK, new AdvancedSearchOnNetworkAction(*this));
+	registerPopupData(ActionCode::SHOW_COLLECTION, myRecentBooksPopupData);
 	addAction(ActionCode::SHOW_OPTIONS, new ShowOptionsDialogAction(*this));
 	addAction(ActionCode::SHOW_CONTENTS, new ShowContentsAction(*this));
 	addAction(ActionCode::SHOW_BOOK_INFO, new ShowBookInfoAction(*this));
-	addAction(ActionCode::ADD_BOOK, new AddBookAction(*this, FBReader::ALL_MODES));
-	addAction(ActionCode::ADD_BOOK_TO_LIBRARY, new AddBookAction(*this, FBReader::BOOK_COLLECTION_MODE));
-	addAction(ActionCode::OPEN_FILE, new AddBookAction(*this, FBReader::BOOK_TEXT_MODE));
-	registerPopupData(ActionCode::OPEN_FILE, myRecentBooksPopupData);
-	addAction(ActionCode::UNDO, new UndoAction(*this, FBReader::BOOK_TEXT_MODE | FBReader::FOOTNOTE_MODE | FBReader::CONTENTS_MODE));
+	addAction(ActionCode::ADD_BOOK, new AddBookAction(*this, FBReader::BOOK_TEXT_MODE | FBReader::BOOK_COLLECTION_MODE | FBReader::CONTENTS_MODE));
+	addAction(ActionCode::UNDO, new UndoAction(*this, FBReader::BOOK_TEXT_MODE));
 	addAction(ActionCode::REDO, new RedoAction(*this));
-	addAction(ActionCode::SEARCH, new SearchAction(*this));
+	addAction(ActionCode::SEARCH, new SearchPatternAction(*this));
 	addAction(ActionCode::FIND_NEXT, new FindNextAction(*this));
 	addAction(ActionCode::FIND_PREVIOUS, new FindPreviousAction(*this));
 	addAction(ActionCode::SCROLL_TO_HOME, new ScrollToHomeAction(*this));
@@ -150,7 +151,6 @@ FBReader::FBReader(const std::string &bookToOpen) :
 	addAction(ActionCode::ROTATE_SCREEN, new RotationAction(*this));
 	addAction(ActionCode::TOGGLE_FULLSCREEN, new FBFullscreenAction(*this));
 	addAction(ActionCode::FULLSCREEN_ON, new FBFullscreenAction(*this));
-	addAction(ActionCode::FULLSCREEN_OFF, new FBFullscreenAction(*this));
 	addAction(ActionCode::CANCEL, new CancelAction(*this));
 	addAction(ActionCode::SHOW_HIDE_POSITION_INDICATOR, new ToggleIndicatorAction(*this));
 	addAction(ActionCode::QUIT, new QuitAction(*this));
@@ -167,9 +167,6 @@ FBReader::FBReader(const std::string &bookToOpen) :
 	addAction(ActionCode::ORGANIZE_BOOKS_BY_AUTHOR, booksOrderAction);
 	addAction(ActionCode::ORGANIZE_BOOKS_BY_TAG, booksOrderAction);
 
-	addAction(ActionCode::HAND_TOOL, new TouchScreenModeAction(*this));
-	addAction(ActionCode::SELECT_TEXT, new TouchScreenModeAction(*this));
-
 	myOpenFileHandler = new OpenFileHandler(*this);
 	ZLCommunicationManager::instance().registerHandler("openFile", myOpenFileHandler);
 }
@@ -306,13 +303,13 @@ void FBReader::openBookInternal(BookDescriptionPtr description) {
 		contentsView.setModel(myModel->contentsModel(), lang);
 		contentsView.setCaption(description->title());
 
-		myRecentBooks.addBook(description->fileName());
+		myRecentBooks.addBook(description);
 		((RecentBooksPopupData&)*myRecentBooksPopupData).updateId();
 	}
 }
 
-void FBReader::tryShowFootnoteView(const std::string &id, bool external) {
-	if (external) {
+void FBReader::tryShowFootnoteView(const std::string &id, const std::string &type) {
+	if (type == "external") {
 		shared_ptr<ProgramCollection> collection = webBrowserCollection();
 		if (!collection.isNull()) {
 			shared_ptr<Program> program = collection->currentProgram();
@@ -320,7 +317,7 @@ void FBReader::tryShowFootnoteView(const std::string &id, bool external) {
 				program->run("openLink", id);
 			}
 		}
-	} else {
+	} else if (type == "internal") {
 		if ((myMode == BOOK_TEXT_MODE) && (myModel != 0)) {
 			BookModel::Label label = myModel->label(id);
 			if (!label.Model.isNull()) {
@@ -336,6 +333,14 @@ void FBReader::tryShowFootnoteView(const std::string &id, bool external) {
 				refreshWindow();
 			}
 		}
+	} else if (type == "book") {
+		DownloadBookRunnable downloader(id);
+		downloader.executeWithUI();
+		if (downloader.hasErrors()) {
+			downloader.showErrorMessage();
+		} else {
+			openFile(downloader.fileName());
+		}
 	}
 }
 
@@ -361,6 +366,7 @@ void FBReader::setMode(ViewMode mode) {
 
 	switch (myMode) {
 		case BOOK_TEXT_MODE:
+			setHyperlinkCursor(false);
 			((ZLTextView&)*myBookTextView).forceScrollbarUpdate();
 			setView(myBookTextView);
 			break;
@@ -375,12 +381,11 @@ void FBReader::setMode(ViewMode mode) {
 			collectionView().openWithBook((myModel != 0) ? myModel->description() : 0);
 			setView(myCollectionView);
 			break;
-		case RECENT_BOOKS_MODE:
-			((RecentBooksView&)*myRecentBooksView).rebuild();
-			setView(myRecentBooksView);
-			break;
 		case BOOKMARKS_MODE:
 			break;
+		case NET_LIBRARY_MODE:
+			setView(myNetLibraryView);
+			break;
 		case UNDEFINED_MODE:
 		case ALL_MODES:
 			break;
@@ -441,18 +446,17 @@ void FBReader::clearTextCaches() {
 	((ZLTextView&)*myFootnoteView).clearCaches();
 	((ZLTextView&)*myContentsView).clearCaches();
 	((ZLTextView&)*myCollectionView).clearCaches();
-	((ZLTextView&)*myRecentBooksView).clearCaches();
+	((ZLTextView&)*myNetLibraryView).clearCaches();
 }
 
-ZLKeyBindings &FBReader::keyBindings() {
+shared_ptr<ZLKeyBindings> FBReader::keyBindings() {
 	return UseSeparateBindingsOption.value() ?
 		keyBindings(rotation()) : myBindings0;
 }
 
-ZLKeyBindings &FBReader::keyBindings(ZLView::Angle angle) {
+shared_ptr<ZLKeyBindings> FBReader::keyBindings(ZLView::Angle angle) {
 	switch (angle) {
 		case ZLView::DEGREES0:
-		default:
 			return myBindings0;
 		case ZLView::DEGREES90:
 			return myBindings90;
@@ -461,6 +465,7 @@ ZLKeyBindings &FBReader::keyBindings(ZLView::Angle angle) {
 		case ZLView::DEGREES270:
 			return myBindings270;
 	}
+	return 0;
 }
 
 shared_ptr<ProgramCollection> FBReader::dictionaryCollection() const {
