@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,14 +35,10 @@
 
 class ZLViewWidget;
 class ZLMessageHandler;
-class ZLPopupData;
 
 class BookModel;
 class BookTextView;
-class FootnoteView;
-class ContentsView;
 class CollectionView;
-class RecentBooksView;
 
 class FBReader : public ZLApplication {
 
@@ -60,7 +56,7 @@ public:
 		CONTENTS_MODE = 1 << 2,
 		BOOKMARKS_MODE = 1 << 3,
 		BOOK_COLLECTION_MODE = 1 << 4,
-		RECENT_BOOKS_MODE = 1 << 5,
+		NET_LIBRARY_MODE = 1 << 5,
 		ALL_MODES = 0x3F
 	};
 
@@ -111,15 +107,15 @@ private:
 	bool isViewFinal() const;
 
 public:
-	ZLKeyBindings &keyBindings();
-	ZLKeyBindings &keyBindings(ZLView::Angle angle);
+	shared_ptr<ZLKeyBindings> keyBindings();
+	shared_ptr<ZLKeyBindings> keyBindings(ZLView::Angle angle);
 
 	bool isDictionarySupported() const;
 	void openInDictionary(const std::string &word);
 
 	shared_ptr<ProgramCollection> webBrowserCollection() const;
 
-	void tryShowFootnoteView(const std::string &id, bool external);
+	void tryShowFootnoteView(const std::string &id, const std::string &type);
 	BookTextView &bookTextView() const;
 	CollectionView &collectionView() const;
 	void showBookTextView();
@@ -145,17 +141,17 @@ private:
 	shared_ptr<ZLView> myBookTextView;	
 	shared_ptr<ZLView> myContentsView;	
 	shared_ptr<ZLView> myCollectionView;	
-	shared_ptr<ZLView> myRecentBooksView;	
+	shared_ptr<ZLView> myNetLibraryView;	
 	shared_ptr<ZLPopupData> myRecentBooksPopupData;	
 
 	ZLTime myLastScrollingTime;
 
 	BookModel *myModel;
 
-	ZLKeyBindings myBindings0;
-	ZLKeyBindings myBindings90;
-	ZLKeyBindings myBindings180;
-	ZLKeyBindings myBindings270;
+	shared_ptr<ZLKeyBindings> myBindings0;
+	shared_ptr<ZLKeyBindings> myBindings90;
+	shared_ptr<ZLKeyBindings> myBindings180;
+	shared_ptr<ZLKeyBindings> myBindings270;
 
 	std::string myBookToOpen;
 	bool myBookAlreadyOpen;
@@ -175,11 +171,10 @@ friend class OpenFileHandler;
 
 friend class OptionsDialog;
 friend class FBView;
-friend class BookTextView;
+friend class NetLibraryView;
 
 //friend class ShowCollectionAction;
 friend class ShowHelpAction;
-//friend class ShowRecentBooksListAction;
 //friend class ShowOptionsDialogAction;
 friend class ShowContentsAction;
 friend class AddBookAction;
@@ -190,6 +185,7 @@ friend class ShowBookInfoAction;
 friend class UndoAction;
 //friend class RedoAction;
 friend class SearchAction;
+friend class SearchPatternAction;
 friend class FindNextAction;
 friend class FindPreviousAction;
 friend class ScrollingAction;
@@ -202,6 +198,8 @@ friend class GotoNextTOCSectionAction;
 friend class GotoPreviousTOCSectionAction;
 //friend class GotoPageNumber;
 friend class SelectionAction;
+friend class SearchOnNetworkAction;
+friend class AdvancedSearchOnNetworkAction;
 friend class FBFullscreenAction;
 };
 
