@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2008-2009 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 
 const std::string ActionCode::SHOW_READING = "showReading";
 const std::string ActionCode::SHOW_COLLECTION = "showLibrary";
+const std::string ActionCode::SHOW_NET_LIBRARY = "showNetLibrary";
 const std::string ActionCode::SHOW_OPTIONS = "preferences";
 const std::string ActionCode::UNDO = "undo";
 const std::string ActionCode::REDO = "redo";
@@ -34,7 +35,7 @@ const std::string ActionCode::SMALL_SCROLL_FORWARD = "smallScrollForward";
 const std::string ActionCode::SMALL_SCROLL_BACKWARD = "smallScrollBackward";
 const std::string ActionCode::MOUSE_SCROLL_FORWARD = "mouseScrollForward";
 const std::string ActionCode::MOUSE_SCROLL_BACKWARD = "mouseScrollBackward";
-const std::string ActionCode::TAP_SCROLL_FORWARD = "tapScroolForward";
+const std::string ActionCode::TAP_SCROLL_FORWARD = "tapScrollForward";
 const std::string ActionCode::TAP_SCROLL_BACKWARD = "tapScrollBackward";
 const std::string ActionCode::SCROLL_TO_HOME = "gotoHome";
 const std::string ActionCode::SCROLL_TO_START_OF_TEXT = "gotoSectionStart";
@@ -45,14 +46,10 @@ const std::string ActionCode::DECREASE_FONT = "decreaseFont";
 const std::string ActionCode::SHOW_HIDE_POSITION_INDICATOR = "toggleIndicator";
 const std::string ActionCode::TOGGLE_FULLSCREEN = "toggleFullscreen";
 const std::string ActionCode::FULLSCREEN_ON = "onFullscreen";
-const std::string ActionCode::FULLSCREEN_OFF = "offFullscreen";
 const std::string ActionCode::ADD_BOOK = "addBook";
-const std::string ActionCode::ADD_BOOK_TO_LIBRARY = "addBookToLibrary";
-const std::string ActionCode::OPEN_FILE = "openFile";
 const std::string ActionCode::SHOW_BOOK_INFO = "bookInfo";
 const std::string ActionCode::SHOW_HELP = "showHelp";
 const std::string ActionCode::ROTATE_SCREEN = "rotate";
-const std::string ActionCode::SHOW_LAST_BOOKS = "showRecent";
 const std::string ActionCode::QUIT = "quit";
 const std::string ActionCode::OPEN_PREVIOUS_BOOK = "previousBook";
 const std::string ActionCode::GOTO_NEXT_TOC_SECTION = "nextTOCSection";
@@ -62,7 +59,7 @@ const std::string ActionCode::CLEAR_SELECTION = "clearSelection";
 const std::string ActionCode::OPEN_SELECTED_TEXT_IN_DICTIONARY = "openInDictionary";
 const std::string ActionCode::GOTO_PAGE_NUMBER = "gotoPageNumber";
 const std::string ActionCode::GOTO_PAGE_NUMBER_WITH_PARAMETER = "gotoPageNumberWithParameter";
-const std::string ActionCode::HAND_TOOL = "handTool";
-const std::string ActionCode::SELECT_TEXT = "selectText";
+const std::string ActionCode::SEARCH_ON_NETWORK = "searchOnNetwork";
+const std::string ActionCode::ADVANCED_SEARCH_ON_NETWORK = "advancedSearchOnNetwork";
 const std::string ActionCode::ORGANIZE_BOOKS_BY_AUTHOR = "byAuthor";
 const std::string ActionCode::ORGANIZE_BOOKS_BY_TAG = "byTag";
