@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@ class ActionCode {
 public:
 	static const std::string SHOW_READING;
 	static const std::string SHOW_COLLECTION;
+	static const std::string SHOW_NET_LIBRARY;
 	static const std::string SHOW_OPTIONS;
 	static const std::string UNDO;
 	static const std::string REDO;
@@ -55,14 +56,10 @@ public:
 	static const std::string SHOW_HIDE_POSITION_INDICATOR;
 	static const std::string TOGGLE_FULLSCREEN;
 	static const std::string FULLSCREEN_ON;
-	static const std::string FULLSCREEN_OFF;
 	static const std::string ADD_BOOK;
-	static const std::string ADD_BOOK_TO_LIBRARY;
-	static const std::string OPEN_FILE;
 	static const std::string SHOW_BOOK_INFO;
 	static const std::string SHOW_HELP;
 	static const std::string ROTATE_SCREEN;
-	static const std::string SHOW_LAST_BOOKS;
 	static const std::string QUIT;
 	static const std::string OPEN_PREVIOUS_BOOK;
 	static const std::string GOTO_NEXT_TOC_SECTION;
@@ -72,8 +69,8 @@ public:
 	static const std::string OPEN_SELECTED_TEXT_IN_DICTIONARY;
 	static const std::string GOTO_PAGE_NUMBER;
 	static const std::string GOTO_PAGE_NUMBER_WITH_PARAMETER;
-	static const std::string HAND_TOOL;
-	static const std::string SELECT_TEXT;
+	static const std::string SEARCH_ON_NETWORK;
+	static const std::string ADVANCED_SEARCH_ON_NETWORK;
 	static const std::string ORGANIZE_BOOKS_BY_AUTHOR;
 	static const std::string ORGANIZE_BOOKS_BY_TAG;
 
@@ -114,26 +111,32 @@ private:
 	FBReader::ViewMode myModeToSet;
 };
 
-class ShowHelpAction : public ModeDependentAction {
+class ShowHelpAction : public FBAction {
 
 public:
 	ShowHelpAction(FBReader &fbreader);
 	void run();
 };
 
-class ShowOptionsDialogAction : public ModeDependentAction {
+class ShowOptionsDialogAction : public FBAction {
 
 public:
 	ShowOptionsDialogAction(FBReader &fbreader);
 	void run();
 };
 
-class ShowContentsAction : public ModeDependentAction {
+class ShowContentsAction : public SetModeAction {
 
 public:
 	ShowContentsAction(FBReader &fbreader);
-	bool isEnabled() const;
-	void run();
+	bool isVisible() const;
+};
+
+class ShowNetworkLibraryAction : public SetModeAction {
+
+public:
+	ShowNetworkLibraryAction(FBReader &fbreader);
+	bool isVisible() const;
 };
 
 class AddBookAction : public ModeDependentAction {
@@ -167,6 +170,7 @@ class ScrollToHomeAction : public ModeDependentAction {
 
 public:
 	ScrollToHomeAction(FBReader &fbreader);
+	bool isEnabled() const;
 	void run();
 };
 
@@ -174,6 +178,7 @@ class ScrollToStartOfTextAction : public ModeDependentAction {
 
 public:
 	ScrollToStartOfTextAction(FBReader &fbreader);
+	bool isEnabled() const;
 	void run();
 };
 
@@ -181,6 +186,7 @@ class ScrollToEndOfTextAction : public ModeDependentAction {
 
 public:
 	ScrollToEndOfTextAction(FBReader &fbreader);
+	bool isEnabled() const;
 	void run();
 };
 
@@ -205,6 +211,12 @@ class SearchAction : public FBAction {
 public:
 	SearchAction(FBReader &fbreader);
 	bool isVisible() const;
+};
+
+class SearchPatternAction : public SearchAction {
+
+public:
+	SearchPatternAction(FBReader &fbreader);
 	void run();
 
 private:
@@ -217,7 +229,7 @@ private:
 friend class SearchPatternEntry;
 };
 
-class FindNextAction : public FBAction {
+class FindNextAction : public SearchAction {
 
 public:
 	FindNextAction(FBReader &fbreader);
@@ -225,7 +237,7 @@ public:
 	void run();
 };
 
-class FindPreviousAction : public FBAction {
+class FindPreviousAction : public SearchAction {
 
 public:
 	FindPreviousAction(FBReader &fbreader);
@@ -304,7 +316,7 @@ private:
 	const std::string myParameter;
 };
 
-class SelectionAction : public ModeDependentAction {
+class SelectionAction : public FBAction {
 
 public:
 	SelectionAction(FBReader &fbreader);
@@ -339,10 +351,17 @@ public:
 	void run();
 };
 
-class TouchScreenModeAction : public ModeDependentAction {
+class SearchOnNetworkAction : public ModeDependentAction {
 
 public:
-	TouchScreenModeAction(FBReader &fbreader);
+	SearchOnNetworkAction(FBReader &fbreader);
+	void run();
+};
+
+class AdvancedSearchOnNetworkAction : public ModeDependentAction {
+
+public:
+	AdvancedSearchOnNetworkAction(FBReader &fbreader);
 	void run();
 };
 
