@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,6 +17,8 @@
  * 02110-1301, USA.
  */
 
+#include <cmath>
+
 #include <ZLUnicodeUtil.h>
 
 #include "FBView.h"
@@ -37,8 +39,8 @@ static const std::string INDICATOR = "Indicator";
 FBIndicatorStyle::FBIndicatorStyle() :
 	TypeOption(ZLCategoryKey::LOOK_AND_FEEL, INDICATOR, "Type", 0, 2, ZLTextPositionIndicatorInfo::OS_SCROLLBAR),
 	IsSensitiveOption(ZLCategoryKey::LOOK_AND_FEEL, INDICATOR, "TouchSensitive", true),
-	ShowTextPositionOption(ZLCategoryKey::LOOK_AND_FEEL, INDICATOR, "PositionText", true),
-	ShowTimeOption(ZLCategoryKey::LOOK_AND_FEEL, INDICATOR, "Time", true),
+	ShowTextPositionOption(ZLCategoryKey::LOOK_AND_FEEL, INDICATOR, "PositionText", false),
+	ShowTimeOption(ZLCategoryKey::LOOK_AND_FEEL, INDICATOR, "Time", false),
 	ColorOption(ZLCategoryKey::LOOK_AND_FEEL, INDICATOR, "Color", ZLColor(127, 127, 127)),
 	HeightOption(ZLCategoryKey::LOOK_AND_FEEL, INDICATOR, "Height", 1, 100, 16),
 	OffsetOption(ZLCategoryKey::LOOK_AND_FEEL, INDICATOR, "Offset", 0, 100, 3),
@@ -79,7 +81,7 @@ int FBIndicatorStyle::fontSize() const {
 
 shared_ptr<ZLTextPositionIndicatorInfo> FBView::ourIndicatorInfo;
 shared_ptr<FBMargins> FBView::ourMargins;
-//shared_ptr<ZLBooleanOption> FBView::ourSelectionOption;
+shared_ptr<ZLBooleanOption> FBView::ourSelectionOption;
 
 FBIndicatorStyle& FBView::commonIndicatorInfo() {
 	if (ourIndicatorInfo.isNull()) {
@@ -120,6 +122,10 @@ void FBView::setCaption(const std::string &caption) {
 }
 
 bool FBView::onStylusPress(int x, int y) {
+	myPressedX = x;
+	myPressedY = y;
+	myIsReleasedWithoutMotion = true;
+
 	if (ZLTextView::onStylusPress(x, y)) {
 		return true;
 	}
@@ -128,18 +134,75 @@ bool FBView::onStylusPress(int x, int y) {
 		return true;
 	}
 
-	if (fbreader().EnableTapScrollingOption.value() &&
+	return true;
+}
+
+bool FBView::_onStylusPress(int, int) {
+	return false;
+}
+
+bool FBView::onStylusRelease(int x, int y) {
+	if (ZLTextView::onStylusRelease(x, y)) {
+		return true;
+	}
+	
+	if (_onStylusRelease(x, y)) {
+		return true;
+	}
+
+	myIsReleasedWithoutMotion =
+		myIsReleasedWithoutMotion && (abs(x - pressedX()) <= 5) && (abs(y - pressedY()) <= 5);
+	if (isReleasedWithoutMotion() &&
+			fbreader().EnableTapScrollingOption.value() &&
 			(!ZLBooleanOption(ZLCategoryKey::EMPTY, ZLOption::PLATFORM_GROUP, ZLOption::FINGER_TAP_DETECTABLE, false).value() ||
 			 !fbreader().TapScrollingOnFingerOnlyOption.value())) {
 		doTapScrolling(y);
 		return true;
 	}
 
-	activateSelection(x, y);
-	return true;
+	return false;
 }
 
-bool FBView::_onStylusPress(int, int) {
+bool FBView::_onStylusRelease(int, int) {
+	return false;
+}
+
+bool FBView::onStylusMove(int x, int y) {
+	if (ZLTextView::onStylusMove(x, y)) {
+		return true;
+	}
+	
+	if (_onStylusMove(x, y)) {
+		return true;
+	}
+
+	return false;
+}
+
+bool FBView::_onStylusMove(int, int) {
+	return false;
+}
+
+bool FBView::onStylusMovePressed(int x, int y) {
+	if (myIsReleasedWithoutMotion) {
+		if ((abs(x - pressedX()) > 5) || (abs(y - pressedY()) > 5)) {
+			myIsReleasedWithoutMotion = false;
+			activateSelection(pressedX(), pressedY());
+		}
+	}
+
+	if (ZLTextView::onStylusMovePressed(x, y)) {
+		return true;
+	}
+	
+	if (_onStylusMovePressed(x, y)) {
+		return true;
+	}
+
+	return false;
+}
+
+bool FBView::_onStylusMovePressed(int, int) {
 	return false;
 }
 
@@ -187,16 +250,23 @@ int FBView::bottomMargin() const {
 	return margins().BottomMarginOption.value();
 }
 
-/*
 ZLBooleanOption &FBView::selectionOption() {
 	if (ourSelectionOption.isNull()) {
 		ourSelectionOption = new ZLBooleanOption(ZLCategoryKey::LOOK_AND_FEEL, OPTIONS, "IsSelectionEnabled", true);
 	}
 	return *ourSelectionOption;
 }
-*/
 
 bool FBView::isSelectionEnabled() const {
-	//return selectionOption().value();
-	return false;
+	return selectionOption().value();
+}
+
+void FBView::scrollAndUpdatePage(bool forward, ScrollingMode mode, unsigned int value) {
+	scrollPage(forward, mode, value);
+	preparePaintInfo();
+	fbreader().refreshWindow();
+}
+
+bool FBView::hasContents() const {
+	return true;
 }
