@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -70,10 +70,16 @@ class FBView : public ZLTextView {
 public:
 	static FBMargins& margins();
 	static FBIndicatorStyle& commonIndicatorInfo();
+	static ZLBooleanOption &selectionOption();
+
+	void scrollAndUpdatePage(bool forward, ScrollingMode mode, unsigned int value);
+
+	virtual bool hasContents() const;
 
 private:
 	static shared_ptr<ZLTextPositionIndicatorInfo> ourIndicatorInfo;
 	static shared_ptr<FBMargins> ourMargins;
+	static shared_ptr<ZLBooleanOption> ourSelectionOption;
 
 protected:
 	void doTapScrolling(int y);
@@ -99,6 +105,16 @@ protected:
 
 	bool onStylusPress(int x, int y);
 	virtual bool _onStylusPress(int x, int y);
+	bool onStylusRelease(int x, int y);
+	virtual bool _onStylusRelease(int x, int y);
+	bool onStylusMove(int x, int y);
+	virtual bool _onStylusMove(int x, int y);
+	bool onStylusMovePressed(int x, int y);
+	virtual bool _onStylusMovePressed(int x, int y);
+
+	int pressedX() const;
+	int pressedY() const;
+	bool isReleasedWithoutMotion() const;
 
 	std::string word(const ZLTextElementArea &area) const;
 
@@ -106,6 +122,10 @@ protected:
 
 private:
 	std::string myCaption;
+
+	int myPressedX;
+	int myPressedY;
+	bool myIsReleasedWithoutMotion;
 };
 
 inline FBReader &FBView::fbreader() { return (FBReader&)application(); }
@@ -118,4 +138,8 @@ inline FBMargins& FBView::margins() {
 	return *ourMargins;
 }
 
+inline int FBView::pressedX() const { return myPressedX; }
+inline int FBView::pressedY() const { return myPressedY; }
+inline bool FBView::isReleasedWithoutMotion() const { return myIsReleasedWithoutMotion; }
+
 #endif /* __FBVIEW_H__ */
