@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -87,7 +87,7 @@ void FormatPlugin::detectLanguage(BookDescription &description, ZLInputStream &s
 	WritableBookDescription(description).language() = language;
 }
 
-const std::string &FormatPlugin::tryOpen(const std::string &path) const {
+const std::string &FormatPlugin::tryOpen(const std::string&) const {
 	static const std::string EMPTY = "";
 	return EMPTY;
 }
