@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,8 +35,7 @@
 #include "../html/HtmlReaderStream.h"
 
 bool CHMPlugin::acceptsFile(const ZLFile &file) const {
-	const std::string &extension = file.extension();
-	return (extension == "CHM") || (extension == "chm");
+	return file.extension() == "chm";
 }
 
 class CHMTextStream : public MergedStream {
