@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 
 #include <cctype>
 
+#include <ZLFile.h>
 #include <ZLFileImage.h>
 #include <ZLStringUtil.h>
 
@@ -137,9 +138,12 @@ void HtmlHrefTagAction::run(const HtmlReader::HtmlTag &tag) {
 					if (value[0] == '#') {
 						setHyperlinkType(INTERNAL_HYPERLINK);
 						bookReader().addHyperlinkControl(INTERNAL_HYPERLINK, value.substr(1));
-					} else if (MiscUtil::isReference(value)) {
-						setHyperlinkType(EXTERNAL_HYPERLINK);
-						bookReader().addHyperlinkControl(EXTERNAL_HYPERLINK, value);
+					} else {
+						FBTextKind hyperlinkType = MiscUtil::referenceType(value);
+						if (hyperlinkType != INTERNAL_HYPERLINK) {
+							setHyperlinkType(hyperlinkType);
+							bookReader().addHyperlinkControl(hyperlinkType, value);
+						}
 					}
 				}
 			}
@@ -170,11 +174,14 @@ void HtmlImageTagAction::run(const HtmlReader::HtmlTag &tag) {
 		bookReader().endParagraph();
 		for (unsigned int i = 0; i < tag.Attributes.size(); ++i) {
 			if (tag.Attributes[i].Name == "SRC") {
-				std::string fileName = MiscUtil::decodeHtmlURL(tag.Attributes[i].Value);
-				bookReader().addImageReference(fileName);
-				bookReader().addImage(fileName,
-					new ZLFileImage("image/auto", myReader.myBaseDirPath + fileName, 0)
-				);
+				const std::string fileName = MiscUtil::decodeHtmlURL(tag.Attributes[i].Value);
+				const std::string filePath = myReader.myBaseDirPath + fileName;
+				if (ZLFile(filePath).exists()) {
+					bookReader().addImageReference(fileName);
+					bookReader().addImage(fileName,
+						new ZLFileImage("image/auto", filePath, 0)
+					);
+				}
 				break;
 			}
 		}
@@ -270,7 +277,7 @@ HtmlStyleTagAction::HtmlStyleTagAction(HtmlBookReader &reader) : HtmlTagAction(r
 }
 
 void HtmlStyleTagAction::run(const HtmlReader::HtmlTag &tag) {
-	myReader.myStyleSheetParser = tag.Start ? new StyleSheetParser(myReader.myStyleSheetTable) : 0;
+	myReader.myStyleSheetParser = tag.Start ? new StyleSheetTableParser(myReader.myStyleSheetTable) : 0;
 	/*
 	if (!tag.Start) {
 		myReader.myStyleSheetTable.dump();
