@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 
 #include <algorithm>
 
+#include <ZLStringUtil.h>
 #include <ZLUnicodeUtil.h>
 #include <ZLFileImage.h>
 
@@ -27,6 +28,7 @@
 #include "../xhtml/XHTMLReader.h"
 #include "../util/MiscUtil.h"
 #include "../../bookmodel/BookModel.h"
+#include "../../constants/XMLNamespace.h"
 
 OEBBookReader::OEBBookReader(BookModel &model) : myModelReader(model) {
 }
@@ -42,7 +44,11 @@ static const std::string ITEMREF = "itemref";
 static const std::string REFERENCE = "reference";
 
 void OEBBookReader::startElementHandler(const char *tag, const char **xmlattributes) {
-	const std::string tagString = ZLUnicodeUtil::toLower(tag);
+	std::string tagString = ZLUnicodeUtil::toLower(tag);
+	if (!myOPFSchemePrefix.empty() &&
+			ZLStringUtil::stringStartsWith(tagString, myOPFSchemePrefix)) {
+		tagString = tagString.substr(myOPFSchemePrefix.length());
+	}
 	if (MANIFEST == tagString) {
 		myState = READ_MANIFEST;
 	} else if (SPINE == tagString) {
@@ -94,7 +100,11 @@ void OEBBookReader::startElementHandler(const char *tag, const char **xmlattribu
 }
 
 void OEBBookReader::endElementHandler(const char *tag) {
-	const std::string tagString = ZLUnicodeUtil::toLower(tag);
+	std::string tagString = ZLUnicodeUtil::toLower(tag);
+	if (!myOPFSchemePrefix.empty() &&
+			ZLStringUtil::stringStartsWith(tagString, myOPFSchemePrefix)) {
+		tagString = tagString.substr(myOPFSchemePrefix.length());
+	}
 	if ((MANIFEST == tagString) || (SPINE == tagString) || (GUIDE == tagString) || (TOUR == tagString)) {
 		myState = READ_NONE;
 	}
@@ -119,7 +129,10 @@ bool OEBBookReader::readBook(const std::string &fileName) {
 
 	XHTMLReader xhtmlReader(myModelReader);
 	for (std::vector<std::string>::const_iterator it = myHtmlFileNames.begin(); it != myHtmlFileNames.end(); ++it) {
-		xhtmlReader.readFile(myFilePrefix, *it, *it);
+		if (it != myHtmlFileNames.begin()) {
+			myModelReader.insertEndOfSectionParagraph();
+		}
+		xhtmlReader.readFile(myFilePrefix + *it, *it);
 	}
 
 	generateTOC();
@@ -167,3 +180,22 @@ void OEBBookReader::generateTOC() {
 		}
 	}
 }
+
+bool OEBBookReader::processNamespaces() const {
+	return true;
+}
+
+void OEBBookReader::namespaceListChangedHandler() {
+	const std::map<std::string,std::string> &namespaceMap = namespaces();
+	std::map<std::string,std::string>::const_iterator iter = namespaceMap.begin();
+	for (; iter != namespaceMap.end(); ++iter) {
+		if (iter->second == XMLNamespace::OpenPackagingFormat) {
+			break;
+		}
+	}
+	if (iter != namespaceMap.end()) {
+		myOPFSchemePrefix = iter->first + ":";
+	} else {
+		myOPFSchemePrefix.erase();
+	}
+}
