@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,11 +17,14 @@
  * 02110-1301, USA.
  */
 
-#include <string.h>
+#include <iostream>
+
+#include <cstring>
 
 #include <ZLFile.h>
 #include <ZLFileImage.h>
 #include <ZLUnicodeUtil.h>
+#include <ZLStringUtil.h>
 
 #include "XHTMLReader.h"
 #include "../util/EntityFilesCollector.h"
@@ -46,6 +49,14 @@ const std::string &XHTMLTagAction::pathPrefix(XHTMLReader &reader) {
 	return reader.myPathPrefix;
 }
 
+void XHTMLTagAction::beginParagraph(XHTMLReader &reader) {
+	reader.beginParagraph();
+}
+
+void XHTMLTagAction::endParagraph(XHTMLReader &reader) {
+	reader.endParagraph();
+}
+
 class XHTMLTagLinkAction : public XHTMLTagAction {
 
 public:
@@ -60,6 +71,13 @@ public:
 	void doAtEnd(XHTMLReader &reader);
 };
 
+class XHTMLTagBodyAction : public XHTMLTagAction {
+
+public:
+	void doAtStart(XHTMLReader &reader, const char **xmlattributes);
+	void doAtEnd(XHTMLReader &reader);
+};
+
 class XHTMLTagRestartParagraphAction : public XHTMLTagAction {
 
 public:
@@ -149,7 +167,7 @@ void XHTMLTagLinkAction::doAtStart(XHTMLReader &reader, const char **xmlattribut
 	if (cssStream.isNull()) {
 		return;
 	}
-	StyleSheetParser parser(reader.myStyleSheetTable);
+	StyleSheetTableParser parser(reader.myStyleSheetTable);
 	parser.parse(*cssStream);
 	//reader.myStyleSheetTable.dump();
 }
@@ -159,34 +177,46 @@ void XHTMLTagLinkAction::doAtEnd(XHTMLReader&) {
 
 void XHTMLTagParagraphAction::doAtStart(XHTMLReader &reader, const char**) {
 	if (!reader.myNewParagraphInProgress) {
-		bookReader(reader).beginParagraph();
+		beginParagraph(reader);
 		reader.myNewParagraphInProgress = true;
 	}
 }
 
 void XHTMLTagParagraphAction::doAtEnd(XHTMLReader &reader) {
-	bookReader(reader).endParagraph();
+	endParagraph(reader);
+}
+
+void XHTMLTagBodyAction::doAtStart(XHTMLReader &reader, const char**) {
+	reader.myInsideBody = true;
+}
+
+void XHTMLTagBodyAction::doAtEnd(XHTMLReader &reader) {
+	endParagraph(reader);
+	reader.myInsideBody = false;
 }
 
 void XHTMLTagRestartParagraphAction::doAtStart(XHTMLReader &reader, const char**) {
-	bookReader(reader).endParagraph();
-	bookReader(reader).beginParagraph();
+	if (reader.myCurrentParagraphIsEmpty) {
+		bookReader(reader).addData(" ");
+	}
+	endParagraph(reader);
+	beginParagraph(reader);
 }
 
 void XHTMLTagRestartParagraphAction::doAtEnd(XHTMLReader&) {
 }
 
 void XHTMLTagItemAction::doAtStart(XHTMLReader &reader, const char**) {
-	bookReader(reader).endParagraph();
+	endParagraph(reader);
 	// TODO: increase left indent
-	bookReader(reader).beginParagraph();
+	beginParagraph(reader);
 	// TODO: replace bullet sign by number inside OL tag
 	const std::string bullet = "\xE2\x80\xA2\xC0\xA0";
 	bookReader(reader).addData(bullet);
 }
 
 void XHTMLTagItemAction::doAtEnd(XHTMLReader &reader) {
-	bookReader(reader).endParagraph();
+	endParagraph(reader);
 }
 
 XHTMLTagImageAction::XHTMLTagImageAction(const std::string &nameAttribute) : myNameAttribute(nameAttribute) {
@@ -194,20 +224,26 @@ XHTMLTagImageAction::XHTMLTagImageAction(const std::string &nameAttribute) : myN
 
 void XHTMLTagImageAction::doAtStart(XHTMLReader &reader, const char **xmlattributes) {
 	const char *fileName = reader.attributeValue(xmlattributes, myNameAttribute.c_str());
-	if (fileName != 0) {
-		bool flag = bookReader(reader).paragraphIsOpen();
-		if (flag) {
-			bookReader(reader).endParagraph();
-		}
-		if ((strlen(fileName) > 2) && strncmp(fileName, "./", 2) == 0) {
-			fileName +=2;
-		}
-		const std::string fullfileName = pathPrefix(reader) + fileName;
-		bookReader(reader).addImageReference(fullfileName);
-		bookReader(reader).addImage(fullfileName, new ZLFileImage("image/auto", fullfileName, 0));
-		if (flag) {
-			bookReader(reader).beginParagraph();
-		}
+	if (fileName == 0) {
+		return;
+	}
+
+	const std::string fullfileName = pathPrefix(reader) + fileName;
+	if (!ZLFile(fullfileName).exists()) {
+		return;
+	}
+
+	bool flag = bookReader(reader).paragraphIsOpen();
+	if (flag) {
+		endParagraph(reader);
+	}
+	if ((strlen(fileName) > 2) && strncmp(fileName, "./", 2) == 0) {
+		fileName +=2;
+	}
+	bookReader(reader).addImageReference(fullfileName);
+	bookReader(reader).addImage(fullfileName, new ZLFileImage("image/auto", fullfileName, 0));
+	if (flag) {
+		beginParagraph(reader);
 	}
 }
 
@@ -231,7 +267,7 @@ void XHTMLTagHyperlinkAction::doAtStart(XHTMLReader &reader, const char **xmlatt
 	const char *href = reader.attributeValue(xmlattributes, "href");
 	if (href != 0) {
 		const std::string link = (*href == '#') ? (reader.myReferenceName + href) : href;
-		FBTextKind hyperlinkType = MiscUtil::isReference(link) ? EXTERNAL_HYPERLINK : INTERNAL_HYPERLINK;
+		const FBTextKind hyperlinkType = MiscUtil::referenceType(link);
 		myHyperlinkStack.push(hyperlinkType);
 		bookReader(reader).addHyperlinkControl(hyperlinkType, link);
 	} else {
@@ -259,23 +295,23 @@ void XHTMLTagParagraphWithControlAction::doAtStart(XHTMLReader &reader, const ch
 		bookReader(reader).insertEndOfSectionParagraph();
 	}
 	bookReader(reader).pushKind(myControl);
-	bookReader(reader).beginParagraph();
+	beginParagraph(reader);
 }
 
 void XHTMLTagParagraphWithControlAction::doAtEnd(XHTMLReader &reader) {
-	bookReader(reader).endParagraph();
+	endParagraph(reader);
 	bookReader(reader).popKind();
 }
 
 void XHTMLTagPreAction::doAtStart(XHTMLReader &reader, const char**) {
 	reader.myPreformatted = true;
-	bookReader(reader).beginParagraph();
+	beginParagraph(reader);
 	bookReader(reader).addControl(CODE, true);
 }
 
 void XHTMLTagPreAction::doAtEnd(XHTMLReader &reader) {
 	bookReader(reader).addControl(CODE, false);
-	bookReader(reader).endParagraph();
+	endParagraph(reader);
 	reader.myPreformatted = false;
 }
 
@@ -288,7 +324,7 @@ XHTMLTagAction *XHTMLReader::addAction(const std::string &tag, XHTMLTagAction *a
 void XHTMLReader::fillTagTable() {
 	if (ourTagActions.empty()) {
 		//addAction("html",	new XHTMLTagAction());
-		addAction("body",	new XHTMLTagParagraphAction());
+		addAction("body",	new XHTMLTagBodyAction());
 		//addAction("title",	new XHTMLTagAction());
 		//addAction("meta",	new XHTMLTagAction());
 		//addAction("script",	new XHTMLTagAction());
@@ -363,31 +399,31 @@ void XHTMLReader::fillTagTable() {
 XHTMLReader::XHTMLReader(BookReader &modelReader) : myModelReader(modelReader) {
 }
 
-bool XHTMLReader::readFile(const std::string &pathPrefix, const std::string &fileName, const std::string &referenceName) {
+bool XHTMLReader::readFile(const std::string &filePath, const std::string &referenceName) {
 	myModelReader.addHyperlinkLabel(referenceName);
 
 	fillTagTable();
 
-	myPathPrefix = pathPrefix;
-	myReferenceName = referenceName;
-
-	myPreformatted = false;
-
-	return readDocument(pathPrefix + fileName);
-}
-
-bool XHTMLReader::readFile(const std::string &pathPrefix, shared_ptr<ZLInputStream> stream, const std::string &referenceName) {
-	myModelReader.addHyperlinkLabel(referenceName);
-
-	fillTagTable();
-
-	myPathPrefix = pathPrefix;
+	myPathPrefix = MiscUtil::htmlDirectoryPrefix(filePath);
 	myReferenceName = referenceName;
 
 	myPreformatted = false;
 	myNewParagraphInProgress = false;
+	myInsideBody = false;
 
-	return readDocument(stream);
+	myCSSStack.clear();
+	myStyleEntryStack.clear();
+	myStylesToRemove = 0;
+
+	return readDocument(filePath);
+}
+
+void XHTMLReader::addStyleEntry(const std::string tag, const std::string aClass) {
+	shared_ptr<ZLTextStyleEntry> entry = myStyleSheetTable.control(tag, aClass);
+	if (!entry.isNull()) {
+		myModelReader.addControl(*entry);
+		myStyleEntryStack.push_back(entry);
+	}
 }
 
 void XHTMLReader::startElementHandler(const char *tag, const char **attributes) {
@@ -405,55 +441,100 @@ void XHTMLReader::startElementHandler(const char *tag, const char **attributes)
 	if (myStyleSheetTable.doBreakBefore(sTag, sClass)) {
 		myModelReader.insertEndOfSectionParagraph();
 	}
+	myDoPageBreakAfterStack.push_back(myStyleSheetTable.doBreakAfter(sTag, sClass));
 
 	XHTMLTagAction *action = ourTagActions[sTag];
 	if (action != 0) {
 		action->doAtStart(*this, attributes);
 	}
 
-	int count = 0;
-	{
-		const ZLTextStyleEntry &entry = myStyleSheetTable.control(sTag, "");
-		if (!entry.isEmpty()) {
-			++count;
-			myModelReader.addControl(entry);
-		}
+	const int sizeBefore = myStyleEntryStack.size();
+	addStyleEntry(sTag, "");
+	addStyleEntry("", sClass);
+	addStyleEntry(sTag, sClass);
+	const char *style = attributeValue(attributes, "style");
+	if (style != 0) {
+		shared_ptr<ZLTextStyleEntry> entry = myStyleParser.parseString(style);
+		myModelReader.addControl(*entry);
+		myStyleEntryStack.push_back(entry);
 	}
-	{
-		const ZLTextStyleEntry &entry = myStyleSheetTable.control("", sClass);
-		if (!entry.isEmpty()) {
-			++count;
-			myModelReader.addControl(entry);
-		}
-	}
-	{
-		const ZLTextStyleEntry &entry = myStyleSheetTable.control(sTag, sClass);
-		if (!entry.isEmpty()) {
-			++count;
-			myModelReader.addControl(entry);
-		}
-	}
-	myCSSStack.push_back(count);
+	myCSSStack.push_back(myStyleEntryStack.size() - sizeBefore);
 }
 
 void XHTMLReader::endElementHandler(const char *tag) {
 	for (int i = myCSSStack.back(); i > 0; --i) {
 		myModelReader.addControl(REGULAR, false);
 	}
+	myStylesToRemove = myCSSStack.back();
 	myCSSStack.pop_back();
+
 	XHTMLTagAction *action = ourTagActions[ZLUnicodeUtil::toLower(tag)];
 	if (action != 0) {
 		action->doAtEnd(*this);
 		myNewParagraphInProgress = false;
 	}
+
+	for (; myStylesToRemove > 0; --myStylesToRemove) {
+		myStyleEntryStack.pop_back();
+	}
+
+	if (myDoPageBreakAfterStack.back()) {
+		myModelReader.insertEndOfSectionParagraph();
+	}
+	myDoPageBreakAfterStack.pop_back();
+}
+
+void XHTMLReader::beginParagraph() {
+	myCurrentParagraphIsEmpty = true;
+	myModelReader.beginParagraph();
+	bool doBlockSpaceBefore = false;
+	for (std::vector<shared_ptr<ZLTextStyleEntry> >::const_iterator it = myStyleEntryStack.begin(); it != myStyleEntryStack.end(); ++it) {
+		myModelReader.addControl(**it);
+		doBlockSpaceBefore =
+			doBlockSpaceBefore ||
+			(*it)->lengthSupported(ZLTextStyleEntry::LENGTH_SPACE_BEFORE);
+	}
+
+	if (doBlockSpaceBefore) {
+		ZLTextStyleEntry blockingEntry;
+		blockingEntry.setLength(
+			ZLTextStyleEntry::LENGTH_SPACE_BEFORE,
+			0,
+			ZLTextStyleEntry::SIZE_UNIT_PIXEL
+		);
+		myModelReader.addControl(blockingEntry);
+	}
+}
+
+void XHTMLReader::endParagraph() {
+	bool doBlockSpaceAfter = false;
+	for (std::vector<shared_ptr<ZLTextStyleEntry> >::const_iterator it = myStyleEntryStack.begin(); it != myStyleEntryStack.end() - myStylesToRemove; ++it) {
+		doBlockSpaceAfter =
+			doBlockSpaceAfter ||
+			(*it)->lengthSupported(ZLTextStyleEntry::LENGTH_SPACE_AFTER);
+	}
+	if (doBlockSpaceAfter) {
+		ZLTextStyleEntry blockingEntry;
+		blockingEntry.setLength(
+			ZLTextStyleEntry::LENGTH_SPACE_AFTER,
+			0,
+			ZLTextStyleEntry::SIZE_UNIT_PIXEL
+		);
+		myModelReader.addControl(blockingEntry);
+	}
+	for (; myStylesToRemove > 0; --myStylesToRemove) {
+		myModelReader.addControl(*myStyleEntryStack.back());
+		myStyleEntryStack.pop_back();
+	}
+	myModelReader.endParagraph();
 }
 
 void XHTMLReader::characterDataHandler(const char *text, size_t len) {
 	if (myPreformatted) {
 		if ((*text == '\r') || (*text == '\n')) {
 			myModelReader.addControl(CODE, false);
-			myModelReader.endParagraph();
-			myModelReader.beginParagraph();
+			endParagraph();
+			beginParagraph();
 			myModelReader.addControl(CODE, true);
 		}
 		size_t spaceCounter = 0;
@@ -463,7 +544,7 @@ void XHTMLReader::characterDataHandler(const char *text, size_t len) {
 		myModelReader.addFixedHSpace(spaceCounter);
 		text += spaceCounter;
 		len -= spaceCounter;
-	} else if (myNewParagraphInProgress) {
+	} else if ((myNewParagraphInProgress) || !myModelReader.paragraphIsOpen()) {
 		while (isspace((unsigned char)*text)) {
 			++text;
 			if (--len == 0) {
@@ -472,6 +553,10 @@ void XHTMLReader::characterDataHandler(const char *text, size_t len) {
 		}
 	}
 	if (len > 0) {
+		myCurrentParagraphIsEmpty = false;
+		if (myInsideBody && !myModelReader.paragraphIsOpen()) {
+			myModelReader.beginParagraph();
+		}
 		myModelReader.addData(std::string(text, len));
 		myNewParagraphInProgress = false;
 	}
