@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2008-2009 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,6 +26,9 @@
 
 class Migration {
 
+public:
+	static int extractVersionInformation(const std::string &name);
+
 protected:
 	static void moveOption(
 		const ZLCategoryKey &oldCategory, const std::string &oldGroup, const std::string &oldName,
@@ -73,4 +76,13 @@ protected:
 	void doMigrationInternal();
 };
 
+class Migration_0_10_4 : public Migration {
+
+public:
+	Migration_0_10_4();
+
+protected:
+	void doMigrationInternal();
+};
+
 #endif /* __MIGRATION_H__ */
