@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2008-2009 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,13 +27,16 @@ MigrationRunnable::MigrationRunnable() :
 }
 
 bool MigrationRunnable::shouldMigrate() const {
-	return myVersionOption.value() < VERSION;
+	return
+		Migration::extractVersionInformation(myVersionOption.value()) <
+		Migration::extractVersionInformation(VERSION);
 }
 
 void MigrationRunnable::run() {
 	Migration_0_8_11().doMigration();
 	Migration_0_8_13().doMigration();
 	Migration_0_8_16().doMigration();
+	Migration_0_10_4().doMigration();
 
 	myVersionOption.setValue(VERSION);
 }
